==> moodle-1.9.7.tgz: moodle/lang/en_utf8/scorm.php <==
<?PHP // $Id: scorm.php,v 1.18.4.13 2009/01/21 16:21:37 wildgirl Exp $ 
      // scorm.php - created with Moodle 1.7 beta + (2006101003)


$string['activation'] = 'Activation';
$string['advanced'] = 'Parameters';
$string['asset'] = 'Asset';
$string['assetlaunched'] = 'Asset - Viewed';
$string['attempt'] = 'attempt';
$string['attempt1'] = '1 attempt';
$string['attempts'] = 'Attempts';
$string['attemptsx'] = '$a attempts';
$string['attr_error'] = 'Bad value for attribute ($a->attr) in tag $a->tag.';
$string['autocontinue'] = 'Auto-Continue';
$string['autocontinuedesc'] = 'This preference sets the default auto continue for the activity';
$string['averageattempt'] = 'Average attempts';
$string['badmanifest'] = 'Some manifest errors: see errors log';
$string['badpackage'] = 'The specified package/manifest is not valid. Check it and try again.';
$string['browse'] = 'Preview';
$string['browsed'] = 'Browsed';
$string['browsemode'] = 'Preview Mode';
$string['browserepository'] = 'Browse repository';
$string['chooseapacket'] = 'Choose or update a package';
$string['completed'] = 'Completed';
$string['confirmloosetracks'] = 'WARNING: The package seems to be changed or modified. If the package structure is changed, some users tracks may be lost during update process.';
$string['contents'] = 'Contents';
$string['coursepacket'] = 'Course package';
$string['package'] = 'Package file';
$string['coursestruct'] = 'Course structure';
$string['datadir'] = 'Filesystem Error: Can\'t create course data directory';
$string['details'] = 'Track details';
$string['directories'] = 'Show the directory links';
$string['display'] = 'Display package';
$string['displaydesc'] = 'This preference sets the default of whether to display the package or not for an activity';
$string['domxml'] = 'DOMXML external library';
$string['element'] = 'Element';
$string['entercourse'] = 'Enter course';
$string['enter'] = 'Enter';
$string['errorlogs'] = 'Errors log';
$string['everyday']= 'Every day';
$string['everytime']= 'Every time it\'s used';
$string['exit'] = 'Exit course';
$string['exitactivity'] = 'Exit activity';
$string['expcoll'] = 'Expand/Collide';
$string['external']= 'Update external packages timing';
$string['failed'] = 'Failed';
$string['firstaccess'] = 'First access';
$string['firstattempt'] = 'First attempt';
$string['found'] = 'Manifest found';
$string['frameheight'] = 'This preference set the default height for stage frame or window';
$string['framewidth'] = 'This preference set the default width for stage frame or window';
$string['fullscreen'] = 'Fill the whole screen';
$string['general'] = 'General data';
$string['gradeaverage'] = 'Average grade';
$string['gradehighest'] = 'Highest grade';
$string['grademethod'] = 'Grading method';
$string['grademethoddesc'] = 'This preference sets the default grade method for an activity';
$string['gradescoes'] = 'Learning Objects';
$string['gradesum'] = 'Sum grade';
$string['height'] = 'Height';
$string['hidden'] = 'Hidden';
$string['hidebrowse'] = 'Disable preview mode';
$string['hidebrowsedesc'] = 'This preference sets the default or whether to disable or enable the preview mode';
$string['hideexit'] = 'Hide exit link';
$string['hidenav'] = 'Hide navigation buttons';
$string['hidenavdesc'] = 'This preference sets the default or whether to show or hide the navigation buttons';
$string['hidereview'] = 'Hide review button';
$string['hidetoc'] = 'Course structure display (TOC)';
$string['hidetocdesc'] = 'This preference sets the default for whether to show or hide the course structure display (TOC)';
$string['highestattempt'] = 'Highest attempt';
$string['identifier'] = 'Question Identifier';
$string['iframe'] = 'Current window';
$string['iframedisplay'] = 'Open package in the current window';
$string['incomplete'] = 'Incomplete';
$string['interactions'] = 'Interactions';
$string['last'] = 'Last accessed on';
$string['lastaccess'] = 'Last access';
$string['lastattempt'] = 'Last attempt';
$string['location'] = 'Show the location bar';
$string['max'] = 'Max score';
$string['maximumattempts'] = 'Number of attempts';
$string['maximumattemptsdesc'] = 'This preference sets the default number of maximum attempts for an activity';
$string['maximumgradedesc'] = 'This preferences sets the default maximum grade for an activity';
$string['menubar'] = 'Show the menu bar';
$string['min'] = 'Min score';
$string['missing_attribute'] = 'Missing attribute $a->attr in tag $a->tag';
$string['missing_tag'] = 'Missing tag $a->tag';
$string['missingparam'] = 'A required is missing or wrong';
$string['mode'] = 'Mode';
$string['modulename'] = 'SCORM/AICC';
$string['modulenameplural'] = 'SCORMs/AICCs';
$string['newattempt'] = 'Start a new attempt';
$string['next'] = 'Continue';
$string['no_attributes'] = 'Tag $a->tag must have attributes';
$string['no_children'] = 'Tag $a->tag must have children';
$string['noactivity'] = 'Nothing to report';
$string['nolimit'] = 'Unlimited attempts';
$string['nomanifest'] = 'Manifest not found';
$string['noprerequisites'] = 'Sorry but you haven\'t reached enough prerequisites to access this learning object';
$string['noreports'] = 'No report to display';
$string['normal'] = 'Normal';
$string['noscriptnoscorm'] = 'Your browser does not support javascript or it has javascript support disabled. This SCORM package may not play or save data correctly.';
$string['not_corr_type'] = 'Type mismatch for tag $a->tag';
$string['notattempted'] = 'Not attempted';
$string['objectives'] = 'Objectives';
$string['onchanges']= 'Whenever it changes';
$string['organization'] = 'Organization';
$string['organizations'] = 'Organizations';
$string['othertracks'] = 'Other Tracks';
$string['packagedir'] = 'Filesystem Error: Can\'t create package directory';
$string['packagefile'] = 'No package file specified';
$string['passed'] = 'Passed';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['popup'] = 'New window';
$string['popupblocked'] = 'If a new window does not appear, $a';
$string['popupblockedlinkname'] = 'click here to launch the activity';
$string['popupmenu'] = 'In a drop down menu';
$string['popupopen'] = 'Open package in a new window';
$string['position_error'] = 'The $a->tag tag can\'t be child of $a->parent tag';
$string['prev'] = 'Previous';
$string['raw'] = 'Raw score';
$string['regular'] = 'Regular Manifest';
$string['deleteallattempts'] = 'Delete all SCORM attempts';
$string['report'] = 'Report';
$string['resizable'] = 'Allow the window to be resized';
$string['result'] = 'Result';
$string['review'] = 'Review';
$string['reviewmode'] = 'Review Mode';
$string['scoes'] = 'Learning Objects';
$string['score'] = 'Score';
$string['scorm:deleteresponses'] = 'Delete SCORM attempts';
$string['scorm:savetrack'] = 'Save tracks';
$string['scorm:skipview'] = 'Skip overview';
$string['scorm:viewreport'] = 'View reports';
$string['scorm:viewscores'] = 'View scores';
$string['scormcourse'] = 'Learning Course';
$string['scormresponsedeleted'] = 'Deleted user attempts';
$string['scrollbars'] = 'Allow the window to be scrolled';
$string['sided'] = 'On the left side';
$string['skipview'] = 'Student skip content structure page';
$string['skipviewdesc'] = 'This preference sets the default of when to skip content structure for a page';
$string['slashargs'] = 'WARNING: slash arguments is disabled on this site and objects may not function as expected!';
$string['stagesize'] = 'Stage size';
$string['started'] = 'Started on';
$string['status'] = 'Status';
$string['statusbar'] = 'Show the status bar';
$string['student_response'] = 'Response';
$string['suspended'] = 'Suspended';
$string['syntax'] = 'Syntax error';
$string['tag_error'] = 'Unknown tag ($a->tag) with this content: $a->value';
$string['time'] = 'Time';
$string['title'] = 'Title';
$string['too_many_attributes'] = 'Tag $a->tag has too many attributes';
$string['too_many_children'] = 'Tag $a->tag has too many children';
$string['toolbar'] = 'Show the toolbar';
$string['totaltime'] = 'Time';
$string['trackingloose'] = 'WARNING: The tracking data of this package will be lost!';
$string['type'] = 'Type';
$string['validateascorm'] = 'Validate a package';
$string['validation'] = 'Validation result';
$string['validationtype'] = 'This preference set the DOMXML library used for validating SCORM Manifest. If you don\'t know leave the selected choice.';
$string['value'] = 'Value';
$string['versionwarning'] = 'The manifest version is older than 1.3, warning at $a->tag tag';
$string['viewallreports'] = 'View reports for $a attempts';
$string['viewalluserreports'] = 'View reports for $a users';
$string['whatgrade'] = 'Attempts grading';
$string['whatgradedesc'] = 'This preference sets the default attempts grading';
$string['width'] = 'Width';
$string['window'] = 'Window';
$string['unziperror'] = 'An error occurs during package unzip';
$string['othersettings'] = 'Additional settings';
$string['updatefreqdesc'] = 'This preference sets the default auto-update frequency of an activity';
$string['updatefreq'] = 'Auto-update frequency';
$string['options'] = 'Options';
$string['activityloading'] = "You will be automatically redirected to the activity in";  // used in conjunction with numseconds
$string['activitypleasewait'] = "Activity loading, please wait ....";
$string['scormloggingon'] = "API Logging is On";
$string['scormloggingoff'] = "API Logging is Off";
?>

==> moodle-1.9.16p0.tgz: moodle/lang/en_utf8/scorm.php <==
<?PHP // $Id: scorm.php,v 1.18.4.15 2010/07/22 02:20:12 danmarsden Exp $ 
      // scorm.php - created with Moodle 1.7 beta + (2006101003)


$string['activation'] = 'Activation';
$string['advanced'] = 'Parameters';
$string['asset'] = 'Asset';
$string['assetlaunched'] = 'Asset - Viewed';
$string['attempt'] = 'attempt';
$string['attempt1'] = '1 attempt';
$string['attempts'] = 'Attempts';
$string['attemptsx'] = '$a attempts';
$string['attr_error'] = 'Bad value for attribute ($a->attr) in tag $a->tag.';
$string['autocontinue'] = 'Auto-Continue';
$string['autocontinuedesc'] = 'This preference sets the default auto continue for the activity';
$string['averageattempt'] = 'Average attempts';
$string['badmanifest'] = 'Some manifest errors: see errors log';
$string['badpackage'] = 'The specified package/manifest is not valid. Check it and try again.';
$string['browse'] = 'Preview';
$string['browsed'] = 'Browsed';
$string['browsemode'] = 'Preview Mode';
$string['browserepository'] = 'Browse repository';
$string['chooseapacket'] = 'Choose or update a package';
$string['completed'] = 'Completed';
$string['confirmloosetracks'] = 'WARNING: The package seems to be changed or modified. If the package structure is changed, some users tracks may be lost during update process.';
$string['contents'] = 'Contents';
$string['coursepacket'] = 'Course package';
$string['package'] = 'Package file';
$string['coursestruct'] = 'Course structure';
$string['datadir'] = 'Filesystem Error: Can\'t create course data directory';
$string['details'] = 'Track details';
$string['directories'] = 'Show the directory links';
$string['display'] = 'Display package';
$string['displaydesc'] = 'This preference sets the default of whether to display the package or not for an activity';
$string['domxml'] = 'DOMXML external library';
$string['element'] = 'Element';
$string['entercourse'] = 'Enter course';
$string['enter'] = 'Enter';
$string['errorlogs'] = 'Errors log';
$string['everyday']= 'Every day';
$string['everytime']= 'Every time it\'s used';
$string['exit'] = 'Exit course';
$string['exitactivity'] = 'Exit activity';
$string['expcoll'] = 'Expand/Collide';
$string['external']= 'Update external packages timing';
$string['failed'] = 'Failed';
$string['finishscorm'] = 'If you have finished viewing this resource, $a';
$string['finishscormlinkname'] = 'click here to return to the course page';
$string['firstaccess'] = 'First access';
$string['firstattempt'] = 'First attempt';
$string['found'] = 'Manifest found';
$string['frameheight'] = 'This preference set the default height for stage frame or window';
$string['framewidth'] = 'This preference set the default width for stage frame or window';
$string['fullscreen'] = 'Fill the whole screen';
$string['general'] = 'General data';
$string['gradeaverage'] = 'Average grade';
$string['gradehighest'] = 'Highest grade';
$string['grademethod'] = 'Grading method';
$string['grademethoddesc'] = 'This preference sets the default grade method for an activity';
$string['gradescoes'] = 'Learning Objects';
$string['gradesum'] = 'Sum grade';
$string['height'] = 'Height';
$string['hidden'] = 'Hidden';
$string['hidebrowse'] = 'Disable preview mode';
$string['hidebrowsedesc'] = 'This preference sets the default or whether to disable or enable the preview mode';
$string['hideexit'] = 'Hide exit link';
$string['hidenav'] = 'Hide navigation buttons';
$string['hidenavdesc'] = 'This preference sets the default or whether to show or hide the navigation buttons';
$string['hidereview'] = 'Hide review button';
$string['hidetoc'] = 'Course structure display (TOC)';
$string['hidetocdesc'] = 'This preference sets the default for whether to show or hide the course structure display (TOC)';
$string['highestattempt'] = 'Highest attempt';
$string['identifier'] = 'Question Identifier';
$string['iframe'] = 'Current window';
$string['iframedisplay'] = 'Open package in the current window';
$string['incomplete'] = 'Incomplete';
$string['interactions'] = 'Interactions';
$string['last'] = 'Last accessed on';
$string['lastaccess'] = 'Last access';
$string['lastattempt'] = 'Last attempt';
$string['location'] = 'Show the location bar';
$string['max'] = 'Max score';
$string['maximumattempts'] = 'Number of attempts';
$string['maximumattemptsdesc'] = 'This preference sets the default number of maximum attempts for an activity';
$string['maximumgradedesc'] = 'This preferences sets the default maximum grade for an activity';
$string['menubar'] = 'Show the menu bar';
$string['min'] = 'Min score';
$string['missing_attribute'] = 'Missing attribute $a->attr in tag $a->tag';
$string['missing_tag'] = 'Missing tag $a->tag';
$string['missingparam'] = 'A required is missing or wrong';
$string['mode'] = 'Mode';
$string['modulename'] = 'SCORM/AICC';
$string['modulenameplural'] = 'SCORMs/AICCs';
$string['newattempt'] = 'Start a new attempt';
$string['next'] = 'Continue';
$string['no_attributes'] = 'Tag $a->tag must have attributes';
$string['no_children'] = 'Tag $a->tag must have children';
$string['noactivity'] = 'Nothing to report';
$string['nolimit'] = 'Unlimited attempts';
$string['nomanifest'] = 'Manifest not found';
$string['noprerequisites'] = 'Sorry but you haven\'t reached enough prerequisites to access this learning object';
$string['noreports'] = 'No report to display';
$string['normal'] = 'Normal';
$string['noscriptnoscorm'] = 'Your browser does not support javascript or it has javascript support disabled. This SCORM package may not play or save data correctly.';
$string['not_corr_type'] = 'Type mismatch for tag $a->tag';
$string['notattempted'] = 'Not attempted';
$string['objectives'] = 'Objectives';
$string['onchanges']= 'Whenever it changes';
$string['organization'] = 'Organization';
$string['organizations'] = 'Organizations';
$string['othertracks'] = 'Other Tracks';
$string['packagedir'] = 'Filesystem Error: Can\'t create package directory';
$string['packagefile'] = 'No package file specified';
$string['passed'] = 'Passed';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['popup'] = 'New window';
$string['popupblockmessage'] = 'If a pop-up window doesn\'t appear, please enable pop-ups in your browser.';
$string['popupmenu'] = 'In a drop down menu';
$string['popupopen'] = 'Open package in a new window';
$string['position_error'] = 'The $a->tag tag can\'t be child of $a->parent tag';
$string['prev'] = 'Previous';
$string['raw'] = 'Raw score';
$string['regular'] = 'Regular Manifest';
$string['deleteallattempts'] = 'Delete all SCORM attempts';
$string['report'] = 'Report';
$string['resizable'] = 'Allow the window to be resized';
$string['result'] = 'Result';
$string['review'] = 'Review';
$string['reviewmode'] = 'Review Mode';
$string['scoes'] = 'Learning Objects';
$string['score'] = 'Score';
$string['scorm:deleteresponses'] = 'Delete SCORM attempts';
$string['scorm:savetrack'] = 'Save tracks';
$string['scorm:skipview'] = 'Skip overview';
$string['scorm:viewreport'] = 'View reports';
$string['scorm:viewscores'] = 'View scores';
$string['scormcourse'] = 'Learning Course';
$string['scormresponsedeleted'] = 'Deleted user attempts';
$string['scrollbars'] = 'Allow the window to be scrolled';
$string['sided'] = 'On the left side';
$string['skipview'] = 'Student skip content structure page';
$string['skipviewdesc'] = 'This preference sets the default of when to skip content structure for a page';
$string['slashargs'] = 'WARNING: slash arguments is disabled on this site and objects may not function as expected!';
$string['stagesize'] = 'Stage size';
$string['started'] = 'Started on';
$string['status'] = 'Status';
$string['statusbar'] = 'Show the status bar';
$string['student_response'] = 'Response';
$string['suspended'] = 'Suspended';
$string['syntax'] = 'Syntax error';
$string['tag_error'] = 'Unknown tag ($a->tag) with this content: $a->value';
$string['time'] = 'Time';
$string['title'] = 'Title';
$string['too_many_attributes'] = 'Tag $a->tag has too many attributes';
$string['too_many_children'] = 'Tag $a->tag has too many children';
$string['toolbar'] = 'Show the toolbar';
$string['totaltime'] = 'Time';
$string['trackingloose'] = 'WARNING: The tracking data of this package will be lost!';
$string['type'] = 'Type';
$string['validateascorm'] = 'Validate a package';
$string['validation'] = 'Validation result';
$string['validationtype'] = 'This preference set the DOMXML library used for validating SCORM Manifest. If you don\'t know leave the selected choice.';
$string['value'] = 'Value';
$string['versionwarning'] = 'The manifest version is older than 1.3, warning at $a->tag tag';
$string['viewallreports'] = 'View reports for $a attempts';
$string['viewalluserreports'] = 'View reports for $a users';
$string['whatgrade'] = 'Attempts grading';
$string['whatgradedesc'] = 'This preference sets the default attempts grading';
$string['width'] = 'Width';
$string['window'] = 'Window';
$string['unziperror'] = 'An error occurs during package unzip';
$string['othersettings'] = 'Additional settings';
$string['updatefreqdesc'] = 'This preference sets the default auto-update frequency of an activity';
$string['updatefreq'] = 'Auto-update frequency';
$string['options'] = 'Options';
$string['activityloading'] = "You will be automatically redirected to the activity in";  // used in conjunction with numseconds
$string['activitypleasewait'] = "Activity loading, please wait ....";
$string['scormloggingon'] = "API Logging is On";
$string['scormloggingoff'] = "API Logging is Off";
?>
